import { HttpClient } from '@angular/common/http';
import {Component, Inject} from '@angular/core';
import {MAT_DIALOG_DATA} from "@angular/material/dialog";

@Component({
  selector: 'app-show-organizational-unit',
  templateUrl: './show-organizational-unit.component.html',
  styleUrl: './show-organizational-unit.component.css'
})
export class ShowOrganizationalUnitComponent {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  displayedColumns: string[] = ['property', 'value'];
  currentCalendar: any;
  ou: any;
  generalData: any[] = [];
  networkData: any[] = [];

  constructor(
    @Inject(MAT_DIALOG_DATA) public data: any,
    private http: HttpClient
  ) {
  }

  ngOnInit(): void {
    this.loadOrganizationalUnit(this.data.data['@id']);
  }

  loadOrganizationalUnit(uuid: string): void {
    console.log(this.data['@id'])
    const apiUrl = `${this.baseUrl}${uuid}`;
    this.http.get<any>(apiUrl).subscribe(
      response => {
        this.ou = response;
        console.log('Organizational unit', this.ou);
        this.initializeData();
      },
      error => {
        console.error('Error loading organizational unit', error);
        this.initializeData();
      });
  }

  loadCurrentCalendar(uuid: string): void {
    const apiUrl = `${this.baseUrl}/remote-calendars/${uuid}`;
    this.http.get<any>(apiUrl).subscribe(
      response => {
        this.currentCalendar = response.name;
        this.initializeData();
      },
      error => {
        console.error('Error loading current calendar', error);
        this.initializeData();
      }
    );
  }

  initializeData(): void {
    this.generalData = [
      { property: 'Nombre', value: this.ou.name },
      { property: 'Uuid', value: this.ou.uuid },
      { property: 'Descripción', value: this.ou.description },
      { property: 'Comentarios', value: this.ou.comments },
      { property: 'Tipo', value: this.ou.type },
      { property: 'Unidad organizativa superior', value: this.ou.parent ? this.ou.parent.name : '-' },
      { property: 'Creado el', value: this.ou.createdAt },
    ];

    this.networkData = [
      { property: 'Calendario asociado', value: this.ou.remoteCalendar ? this.currentCalendar : '-' },
      { property: 'Aforo', value: this.ou.capacity },
      { property: 'Localización', value: this.ou.location },
      { property: 'Calendario', value: this.ou.calendar ? this.ou.calendar.name : '-' },
      { property: 'Proyector', value: this.ou.projector },
      { property: 'Pizarra', value: this.ou.board },
      { property: 'OgLive', value: this.ou.networkSettings.ogLive ? this.ou.networkSettings.ogLive.name : '-' },
      { property: 'Repositorio', value: this.ou.networkSettings.repository ? this.ou.networkSettings.repository.name : '-' },
      { property: 'OgLog', value: this.ou.networkSettings.oglog },
      { property: 'OgShare', value: this.ou.networkSettings.ogshare },
      { property: 'Perfil de hardware', value: this.ou.networkSettings.hardwareProfile ? this.ou.networkSettings.hardwareProfile.name : '-' },
      { property: 'Máscara de red', value: this.ou.networkSettings.netmask },
    ]
  }
}
