import {Component, Inject, OnInit} from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {ToastrService} from "ngx-toastr";
import {Router} from "@angular/router";

@Component({
  selector: 'app-export-image',
  templateUrl: './export-image.component.html',
  styleUrl: './export-image.component.css'
})
export class ExportImageComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  loading: boolean = true;
  repositories: any[] = [];
  selectedRepository: string = '';

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<ExportImageComponent>,
    private toastService: ToastrService,
    private router: Router,
    @Inject(MAT_DIALOG_DATA) public data: { image: any }
  ) {

  }

  ngOnInit(): void {
    this.loading = true;
    this.loadRepositories();
  }

  loadRepositories() {
    this.http.get<any>(`${this.baseUrl}/image-repositories?id[ne]=1&page=1&itemsPerPage=50`).subscribe(
      response => {
        this.repositories = response['hydra:member'];
        this.loading = false;
      },
      error => console.error('Error fetching organizational units:', error)
    );
  }

  save() {
    this.http.post<any>(`${this.baseUrl}${this.selectedRepository}/export-image`, {
      images: [this.data.image['@id']]
    }).subscribe({
      next: (response) => {
        this.toastService.success('Imagen exportada correctamente');
        this.dialogRef.close();
        this.router.navigate(['/commands-logs']);
      },
      error: error => {
        console.error('Error al exportar imagen:', error);
        this.toastService.error('Error al exportar imagen');
      }
    });
  }

  close() {
    this.dialogRef.close();
  }
}
